=== modified file 'bzrlib/branch.py'
--- bzrlib/branch.py	2012-07-02 18:21:51 +0000
+++ bzrlib/branch.py	2012-07-06 11:27:16 +0000
@@ -2398,9 +2398,6 @@
         """
         if not self.is_locked():
             self._note_lock('w')
-        # All-in-one needs to always unlock/lock.
-        repo_control = getattr(self.repository, 'control_files', None)
-        if self.control_files == repo_control or not self.is_locked():
             self.repository._warn_if_deprecated(self)
             self.repository.lock_write()
             took_lock = True
@@ -2421,9 +2418,6 @@
         """
         if not self.is_locked():
             self._note_lock('r')
-        # All-in-one needs to always unlock/lock.
-        repo_control = getattr(self.repository, 'control_files', None)
-        if self.control_files == repo_control or not self.is_locked():
             self.repository._warn_if_deprecated(self)
             self.repository.lock_read()
             took_lock = True
@@ -2444,12 +2438,8 @@
         try:
             self.control_files.unlock()
         finally:
-            # All-in-one needs to always unlock/lock.
-            repo_control = getattr(self.repository, 'control_files', None)
-            if (self.control_files == repo_control or
-                not self.control_files.is_locked()):
-                self.repository.unlock()
             if not self.control_files.is_locked():
+                self.repository.unlock()
                 # we just released the lock
                 self._clear_cached_state()
 

=== modified file 'bzrlib/gpg.py'
--- bzrlib/gpg.py	2012-03-12 12:35:59 +0000
+++ bzrlib/gpg.py	2012-06-29 08:12:32 +0000
@@ -213,7 +213,7 @@
             # use the user email address
             key = config.extract_email_address(self._config_stack.get('email'))
         return [self._config_stack.get('gpg_signing_command'), '--clearsign',
-                '-u', key, '--no-tty']
+                '-u', key]
 
     def sign(self, content):
         if isinstance(content, unicode):

=== modified file 'bzrlib/plugins/weave_fmt/branch.py'
--- bzrlib/plugins/weave_fmt/branch.py	2012-03-30 18:36:46 +0000
+++ bzrlib/plugins/weave_fmt/branch.py	2012-07-06 11:27:16 +0000
@@ -23,10 +23,17 @@
     lockable_files,
     )
 
+from bzrlib.decorators import (
+    needs_read_lock,
+    needs_write_lock,
+    only_raises,
+    )
+from bzrlib.lock import LogicalLockResult
 from bzrlib.trace import mutter
 
 from bzrlib.branch import (
     BranchFormat,
+    BranchWriteLockResult,
     )
 from bzrlib.branchfmt.fullhistory import (
     FullHistoryBzrBranch,
@@ -36,6 +43,55 @@
 class BzrBranch4(FullHistoryBzrBranch):
     """Branch format 4."""
 
+    def lock_write(self, token=None):
+        """Lock the branch for write operations.
+
+        :param token: A token to permit reacquiring a previously held and
+            preserved lock.
+        :return: A BranchWriteLockResult.
+        """
+        if not self.is_locked():
+            self._note_lock('w')
+        # All-in-one needs to always unlock/lock.
+        self.repository._warn_if_deprecated(self)
+        self.repository.lock_write()
+        try:
+            return BranchWriteLockResult(self.unlock,
+                self.control_files.lock_write(token=token))
+        except:
+            self.repository.unlock()
+            raise
+
+    def lock_read(self):
+        """Lock the branch for read operations.
+
+        :return: A bzrlib.lock.LogicalLockResult.
+        """
+        if not self.is_locked():
+            self._note_lock('r')
+        # All-in-one needs to always unlock/lock.
+        self.repository._warn_if_deprecated(self)
+        self.repository.lock_read()
+        try:
+            self.control_files.lock_read()
+            return LogicalLockResult(self.unlock)
+        except:
+            self.repository.unlock()
+            raise
+
+    @only_raises(errors.LockNotHeld, errors.LockBroken)
+    def unlock(self):
+        if self.control_files._lock_count == 2 and self.conf_store is not None:
+            self.conf_store.save_changes()
+        try:
+            self.control_files.unlock()
+        finally:
+            # All-in-one needs to always unlock/lock.
+            self.repository.unlock()
+            if not self.control_files.is_locked():
+                # we just released the lock
+                self._clear_cached_state()
+
     def _get_checkout_format(self, lightweight=False):
         """Return the most suitable metadir for a checkout of this branch.
         """

=== modified file 'bzrlib/remote.py'
--- bzrlib/remote.py	2012-06-26 12:33:14 +0000
+++ bzrlib/remote.py	2012-06-28 16:17:34 +0000
@@ -2160,13 +2160,6 @@
         self._ensure_real()
         self._real_repository.create_bundle(target, base, fileobj, format)
 
-    @needs_read_lock
-    @symbol_versioning.deprecated_method(
-        symbol_versioning.deprecated_in((2, 4, 0)))
-    def get_ancestry(self, revision_id, topo_sorted=True):
-        self._ensure_real()
-        return self._real_repository.get_ancestry(revision_id, topo_sorted)
-
     def fileids_altered_by_revision_ids(self, revision_ids):
         self._ensure_real()
         return self._real_repository.fileids_altered_by_revision_ids(revision_ids)

=== modified file 'bzrlib/repository.py'
--- bzrlib/repository.py	2012-06-26 14:26:44 +0000
+++ bzrlib/repository.py	2012-06-28 16:17:34 +0000
@@ -1023,40 +1023,6 @@
         """
         raise NotImplementedError(self.revision_trees)
 
-    @needs_read_lock
-    @symbol_versioning.deprecated_method(
-        symbol_versioning.deprecated_in((2, 4, 0)))
-    def get_ancestry(self, revision_id, topo_sorted=True):
-        """Return a list of revision-ids integrated by a revision.
-
-        The first element of the list is always None, indicating the origin
-        revision.  This might change when we have history horizons, or
-        perhaps we should have a new API.
-
-        This is topologically sorted.
-        """
-        if 'evil' in debug.debug_flags:
-            mutter_callsite(2, "get_ancestry is linear with history.")
-        if _mod_revision.is_null(revision_id):
-            return [None]
-        if not self.has_revision(revision_id):
-            raise errors.NoSuchRevision(self, revision_id)
-        graph = self.get_graph()
-        keys = set()
-        search = graph._make_breadth_first_searcher([revision_id])
-        while True:
-            try:
-                found, ghosts = search.next_with_ghosts()
-            except StopIteration:
-                break
-            keys.update(found)
-        if _mod_revision.NULL_REVISION in keys:
-            keys.remove(_mod_revision.NULL_REVISION)
-        if topo_sorted:
-            parent_map = graph.get_parent_map(keys)
-            keys = tsort.topo_sort(parent_map)
-        return [None] + list(keys)
-
     def pack(self, hint=None, clean_obsolete_packs=False):
         """Compress the data within the repository.
 

=== modified file 'bzrlib/tests/per_branch/test_config.py'
--- bzrlib/tests/per_branch/test_config.py	2011-02-18 11:24:21 +0000
+++ bzrlib/tests/per_branch/test_config.py	2012-06-30 06:10:05 +0000
@@ -35,4 +35,12 @@
         config.set_user_option('name', value_dict.copy())
         self.assertEqual(value_dict, config.get_user_option('name'))
 
+    def test_set_submit_branch(self):
+        # Make sure setting a config option persists on disk
+        b = self.make_branch('.')
+        b.set_submit_branch('foo')
+        # Refresh the branch
+        b = branch.Branch.open('.')
+        self.assertEquals('foo', b.get_submit_branch())
+
 

=== modified file 'bzrlib/tests/per_repository_vf/test_repository.py'
--- bzrlib/tests/per_repository_vf/test_repository.py	2011-11-29 18:37:21 +0000
+++ bzrlib/tests/per_repository_vf/test_repository.py	2012-06-26 12:30:00 +0000
@@ -383,22 +383,6 @@
         self.assertEqual(set(['rev1', 'rev2', 'rev3', 'rev4']),
             set(self.bzrdir.open_repository().all_revision_ids()))
 
-    def test_get_ancestry_missing_revision(self):
-        # get_ancestry(revision that is in some data but not fully installed
-        # -> NoSuchRevision
-        repo = self.bzrdir.open_repository()
-        self.assertRaises(errors.NoSuchRevision,
-            self.applyDeprecated, deprecated_in((2, 4, 0)),
-            repo.get_ancestry, 'orphan')
-
-    def test_get_unordered_ancestry(self):
-        repo = self.bzrdir.open_repository()
-        self.assertEqual(
-            set(self.applyDeprecated(deprecated_in((2, 4, 0)),
-                repo.get_ancestry, 'rev3')),
-            set(self.applyDeprecated(deprecated_in((2, 4, 0)),
-                repo.get_ancestry, 'rev3', topo_sorted=False)))
-
     def test_reserved_id(self):
         repo = self.make_repository('repository')
         repo.lock_write()

=== modified file 'bzrlib/tests/test_gpg.py'
--- bzrlib/tests/test_gpg.py	2012-02-26 19:21:01 +0000
+++ bzrlib/tests/test_gpg.py	2012-06-26 23:04:30 +0000
@@ -51,7 +51,7 @@
         self.my_gpg = gpg.GPGStrategy(FakeConfig())
 
     def test_signing_command_line(self):
-        self.assertEqual(['false',  '--clearsign', '-u', 'amy@example.com', '--no-tty'],
+        self.assertEqual(['false',  '--clearsign', '-u', 'amy@example.com'],
                          self.my_gpg._command_line())
 
     def test_signing_command_line_from_default(self):
@@ -60,7 +60,7 @@
 email=Amy <amy@example.com>
 gpg_signing_key=default
 gpg_signing_command=false'''))
-        self.assertEqual(['false',  '--clearsign', '-u', 'amy@example.com', '--no-tty'],
+        self.assertEqual(['false',  '--clearsign', '-u', 'amy@example.com'],
                          my_gpg._command_line())
 
     def test_signing_command_line_from_email(self):
@@ -68,7 +68,7 @@
         my_gpg = gpg.GPGStrategy(FakeConfig('''
 email=Amy <amy@example.com>
 gpg_signing_command=false'''))
-        self.assertEqual(['false',  '--clearsign', '-u', 'amy@example.com', '--no-tty'],
+        self.assertEqual(['false',  '--clearsign', '-u', 'amy@example.com'],
                          my_gpg._command_line())
 
     def test_checks_return_code(self):

=== modified file 'doc/en/release-notes/bzr-2.5.txt'
--- doc/en/release-notes/bzr-2.5.txt	2012-06-18 11:43:07 +0000
+++ doc/en/release-notes/bzr-2.5.txt	2012-06-29 08:12:32 +0000
@@ -32,6 +32,8 @@
 .. Fixes for situations where bzr would previously crash or give incorrect
    or undesirable results.
 
+* Revert use of --no-tty when gpg signing commits. (Jelmer Vernooij, #1014570)
+
 Documentation
 *************
 

=== modified file 'doc/en/release-notes/bzr-2.6.txt'
--- doc/en/release-notes/bzr-2.6.txt	2012-06-26 15:40:44 +0000
+++ doc/en/release-notes/bzr-2.6.txt	2012-07-05 15:44:32 +0000
@@ -41,9 +41,13 @@
 * "bzr missing" now shows tag names when displaying revision information.
   (#559072, Neil Martinsen-Burrell)
 
+* Fix ``branch.conf`` saving when unlocking the branch for BranchFormat4.
+  (Vincent Ladeuil, #1020007)
+
 * Implement ``ResponseFile.readline`` and ``ReponseFile.tell``,
   fixing some clones over HTTP. (Jelmer Vernooij, #963769)
 
+
 Documentation
 *************
 
@@ -58,6 +62,8 @@
 .. Changes that may require updates in plugins or other code that uses
    bzrlib.
 
+* Remove deprecated Repository.get_ancestry(). (Jelmer Vernooij)
+
 * Remove deprecated Branch.import_last_revision(). (Jelmer Vernooij)
 
 * Remove deprecated Repository.iter_reverse_revision_history().

